import {
  app,
  BrowserWindow
} from 'electron'
import action from "./model/action"
import store from "../renderer/store"

/**
 * Set `__static` path to static files in production
 * https://simulatedgreg.gitbooks.io/electron-vue/content/en/using-static-assets.html
 */
if (process.env.NODE_ENV !== 'development') {
  global.__static = require('path').join(__dirname, '/static').replace(/\\/g, '\\\\')
}
const electronLocalshortcut = require('electron-localshortcut');
let mainWindow
const winURL = process.env.NODE_ENV === 'development' ?
  `http://localhost:9080` :
  `file://${__dirname}/index.html`

function createWindow() {
  /**
   * Initial window options
   */
  mainWindow = new BrowserWindow({
    height: 563,
    useContentSize: true,
    width: 1000,
    webPreferences: {
      nodeIntegration: true
    }
  })

  mainWindow.loadURL(winURL)

  mainWindow.on('closed', () => {
    mainWindow = null
  })
  store.subscribe((mutation,state)=>{
    console.log('mutation:',mutation);
    if(mutation.payload.name=='file'){
      mainWindow.setTitle(mutation.payload.value);
    }
    console.log('state:',state);
  })
  // 去掉顶部菜单
  mainWindow.setMenu(null)

  require('./model/menu.js');
  electronLocalshortcut.register(mainWindow, 'Ctrl+S', () => {
    action.save();
  });
  electronLocalshortcut.register(mainWindow, 'Ctrl+E', () => {
    action.saveAs();
  });
  electronLocalshortcut.register(mainWindow, 'Ctrl+O', () => {
    action.open();
  });
  electronLocalshortcut.register(mainWindow, 'Ctrl+D', () => {
    action.openSetting();
  });
  electronLocalshortcut.register(mainWindow, 'Ctrl+C', () => {
    action.copy();
  });
}

app.on('ready', createWindow)

app.on('window-all-closed', () => {
  if (process.platform !== 'darwin') {
    app.quit()
  }
})

app.on('activate', () => {
  if (mainWindow === null) {
    createWindow()
  }
})

/**
 * Auto Updater
 *
 * Uncomment the following code below and install `electron-updater` to
 * support auto updating. Code Signing with a valid certificate is required.
 * https://simulatedgreg.gitbooks.io/electron-vue/content/en/using-electron-builder.html#auto-updating
 */

/*
import { autoUpdater } from 'electron-updater'

autoUpdater.on('update-downloaded', () => {
  autoUpdater.quitAndInstall()
})

app.on('ready', () => {
  if (process.env.NODE_ENV === 'production') autoUpdater.checkForUpdates()
})
 */
